#
# spec file for package csound
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define support_fltk 0

Name:           csound
BuildRequires:  alsa-devel
BuildRequires:  bison
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  fluidsynth-devel
BuildRequires:  gcc-c++
BuildRequires:  jack-devel
BuildRequires:  liblo-devel
BuildRequires:  libsndfile-devel
BuildRequires:  portaudio-devel
BuildRequires:  python-devel
BuildRequires:  scons
BuildRequires:  swig
%if %support_fltk
BuildRequires:  fltk-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  xorg-x11-devel
%endif
Version:        5.18.02
Release:        lp151.2.3
Summary:        Computer Sound Synthesis and Composition Program
License:        GFDL-1.2 and LGPL-2.1+ and MIT
Group:          Productivity/Multimedia/Sound/Utilities
Url:            http://www.csounds.com
Source:         Csound%{version}.tar.gz
Source1:        README.SUSE
Patch0:         csound-scons-on-py3.patch
Patch3:         %{name}-strncat-fix.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Csound is a software synthesis program. It is fully modular and
supports an unlimited amount of oscillators and filters.

%package devel
Summary:        Development files for Csound, a sound synthesis program
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Provides:       %{name}-devel-static = %{version}

%description devel
Development files for Csound.

%prep
%setup -q -n Csound%{version}
%patch0 -p1
%patch3
# remove __DATE__ from source files, causes unnecessary rebuilds
sed -i 's:__DATE__:"":' Engine/musmon.c frontends/CsoundVST/CsoundVstFltk.cpp Top/main.c
# copy readme
cp %{SOURCE1} .
# fix encoding
iconv -f latin1 -t utf8 readme-csound5.txt > README
test -f custom.py || cp custom.py.mkg custom.py

%build
%if %{_lib} == "lib64"
args="Word64=1"
%else
args=""
%endif
scons prefix=%{_prefix} buildRelease=1 $args \
  customCCFLAGS="%{optflags} -fno-strict-aliasing" \
  customCXXFLAGS="%{optflags} -fno-strict-aliasing"

%install
%if %{_lib} == "lib64"
args="--word64"
%else
args=""
%endif
./install.py --prefix=%{_prefix} --instdir=%{buildroot} $args
rm -f %{buildroot}%{_prefix}/csound5-*.md5sums %{buildroot}%{_bindir}/uninstall-csound5
rm -rf %{buildroot}%{_datadir}/doc/csound
# rename conflicting binary names
mv %{buildroot}%{_bindir}/sndinfo %{buildroot}%{_bindir}/csndinfo
mv %{buildroot}%{_bindir}/extract %{buildroot}%{_bindir}/csound-extract
%fdupes -s %{buildroot}
%find_lang %{name}5

%files -f %{name}5.lang
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog README README.SUSE
%{_bindir}/*
%{_libdir}/csound/

%files devel
%defattr(-,root,root)
%{_includedir}/csound/
%{_libdir}/libcsound.a

%changelog
* Thu Nov 23 2017 dimstar@opensuse.org
- Add csound-scons-on-py3.patch: Fix build with scons using python3
  as interpreter.
* Wed Nov  8 2017 dimstar@opensuse.org
- Rename README.SuSE to README.SUSE, adhering to the correct
  spelling.
* Sat Feb 11 2017 jengelh@inai.de
- Fix RPM groups, trim descriptions from repeated information.
  Remove unnecessary ldconfig calls (they do not apply for
  plugin directories).
* Mon Jan 16 2017 bwiedemann@suse.com
- drop useless uninstall script and make build reproducible
* Tue Nov  6 2012 tiwai@suse.de
- updated to version 5.18.02, including previous security fixes:
  this fixes the build failure on FACTORY with new bison, too;
  see ChangeLog for detailed updates and fixes
* Wed Apr 18 2012 tiwai@suse.de
- VUL-0: csound: buffer overflow in pv_import (CVE-2012-2106,
  bnc#757254),
  VUL-0: csound: buffer overflow in lpc_import (CVE-2012-2107,
  bnc#757255),
  VUL-0: csound: Stack-based buffer overflow in lpc_import
  (CVE-2012-2108, bnc#757256):
  a single patch for all three issues
* Mon Feb 27 2012 tiwai@suse.de
- updated to version 5.16.6, including a fix for
  VUL-0: CVE-2012-0270: csound: two buffer overflow flaws in
  getnum() (bnc#749073)
- drop obsoleted patches
* Sun Jan  8 2012 prusnak@opensuse.org
- updated to version 5.15.0
- drop unused patches
- fix wrong memset and strncat usage ({memset,strncat}-fix.patch)
- create -devel subpackage
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Thu Jul 16 2009 tiwai@suse.de
- fix scons argument to build for 64bit archs (bnc#521979)
* Wed Jan 28 2009 tiwai@suse.de
- Fix python module search path insecure issue (bnc#470095)
  This package is unaffected; the patch is included just for any
  possible cases in future.
* Wed Oct  1 2008 tiwai@suse.de
- fix build with python-2.6
* Wed Jun 20 2007 tiwai@suse.de
- fix fdupes usage
* Mon Jun 11 2007 tiwai@suse.de
- updated to version 5.06:
  * fix k-rate, vrandh and vrandi scaling problems, mod fix
  * new opcodes: partikkel, partikkelsync
* Tue Mar 27 2007 tiwai@suse.de
- update to version 5.05:
  * fixes/improvements on FLTK support
  * fix heap overflow
  * clean up old codes
* Mon Jan 22 2007 tiwai@suse.de
- major update to version 5.04
  (not built with fltk due to lack of threading support)
* Mon Mar 27 2006 pth@suse.de
- Add missing parameter in printf call (bug #129676).
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Oct 15 2004 tiwai@suse.de
- renamed extract to csound-extract to avoid name confliction
  (bug #45347).
* Wed Jun  2 2004 tiwai@suse.de
- fixed the ALSA RT plugin with the new API.
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig and %%defattr
* Tue Aug  5 2003 tiwai@suse.de
- renamed sndinfo to csndinfo to avoid name confliction with snd.
* Wed Jul 30 2003 tiwai@suse.de
- fixed the build on x86-64.
* Mon Jul 28 2003 tiwai@suse.de
- updated to 4.24.1.
- fixed tmpnam with mkstemp.
* Thu Feb  1 2001 tiwai@suse.de
- Initial vesrion: unofficial-4.10.0.0c
